@@ -26,7 +26,7 @@
 #include <fx2lafw.h>
 #include <gpif-acquisition.h>
 
-__bit gpif_acquiring;
+enum gpif_status gpif_acquiring = STOPPED;
 
 static void gpif_reset_waveforms(void)
 {
@@ -62,7 +62,7 @@ static void gpif_setup_registers(void)
 	 * GPIFWFSELECT: [7:6] = SINGLEWR index, [5:4] = SINGLERD index,
 	 *               [3:2] = FIFOWR index, [1:0] = FIFORD index
 	 */
-	GPIFWFSELECT = (0x3 << 6) | (0x2 << 4) | (0x1 << 2) | (0x0 << 0);
+	GPIFWFSELECT = (0x3u << 6) | (0x2u << 4) | (0x1u << 2) | (0x0u << 0);
 
 	/* Contains RDY* pin values. Read-only according to TRM. */
 	GPIFREADYSTAT = 0;
@@ -125,7 +125,7 @@ void gpif_init_la(void)
 	gpif_init_flowstates();
 
 	/* Reset the status. */
-	gpif_acquiring = FALSE;
+	gpif_acquiring = STOPPED;
 }
 
 static void gpif_make_delay_state(volatile BYTE *pSTATE, uint8_t delay, uint8_t output)
@@ -183,7 +183,7 @@ static void gpif_make_data_dp_state(volatile BYTE *pSTATE)
 	pSTATE[24] = (6 << 3) | (6 << 0);
 }
 
-bool gpif_acquisition_start(const struct cmd_start_acquisition *cmd)
+bool gpif_acquisition_prepare(const struct cmd_start_acquisition *cmd)
 {
 	int i;
 	volatile BYTE *pSTATE = &GPIF_WAVE_DATA;
@@ -238,6 +238,14 @@ bool gpif_acquisition_start(const struct cmd_start_acquisition *cmd)
 	/* Populate S1 - the decision point. */
 	gpif_make_data_dp_state(pSTATE++);
 
+	/* Update the status. */
+	gpif_acquiring = PREPARED;
+
+	return true;
+}
+
+void gpif_acquisition_start(void)
+{
 	/* Execute the whole GPIF waveform once. */
 	gpif_set_tc16(1);
 
@@ -245,15 +253,13 @@ bool gpif_acquisition_start(const struct cmd_start_acquisition *cmd)
 	gpif_fifo_read(GPIF_EP2);
 
 	/* Update the status. */
-	gpif_acquiring = TRUE;
-
-	return true;
+	gpif_acquiring = RUNNING;
 }
 
 void gpif_poll(void)
 {
 	/* Detect if acquisition has completed. */
-	if (gpif_acquiring && (GPIFTRIG & 0x80)) {
+	if ((gpif_acquiring == RUNNING) && (GPIFTRIG & 0x80)) {
 		/* Activate NAK-ALL to avoid race conditions. */
 		FIFORESET = 0x80;
 		SYNCDELAY();
@@ -274,6 +280,6 @@ void gpif_poll(void)
 		FIFORESET = 0x00;
 		SYNCDELAY();
 
-		gpif_acquiring = FALSE;
+		gpif_acquiring = STOPPED;
 	}
 }
