@@ -23,8 +23,16 @@
 #include <stdbool.h>
 #include <command.h>
 
+enum gpif_status {
+	STOPPED = 0,
+	PREPARED,
+	RUNNING,
+};
+extern enum gpif_status gpif_acquiring;
+
 void gpif_init_la(void);
-bool gpif_acquisition_start(const struct cmd_start_acquisition *cmd);
+bool gpif_acquisition_prepare(const struct cmd_start_acquisition *cmd);
+void gpif_acquisition_start(void);
 void gpif_poll(void);
 
 #endif
